Index: tools/gpu/vk/VkTestContext.cpp |
diff --git a/tools/gpu/vk/VkTestContext.cpp b/tools/gpu/vk/VkTestContext.cpp |
index 44be9fd2425813d144f9920ca6480a72ce380c5b..f6849e4484606af5d58f237729db67838b08efac 100644 |
--- a/tools/gpu/vk/VkTestContext.cpp |
+++ b/tools/gpu/vk/VkTestContext.cpp |
@@ -10,7 +10,7 @@ |
#ifdef SK_VULKAN |
namespace { |
// TODO: Implement fence syncs and swap buffers |
class VkTestContextImpl : public sk_gpu_test::VkTestContext { |
public: |
VkTestContextImpl() |
@@ -20,6 +20,9 @@ public: |
void testAbandon() override {} |
+ void submit() override {} |
+ void finish() override {} |
+ |
protected: |
void teardown() override { fVk.reset(nullptr); } |
@@ -10,7 +10,7 @@ |
#ifdef SK_VULKAN |
namespace { |
-// TODO: Implement fence syncs and swap buffers |
+// TODO: Implement fence syncs, swap buffers, submit, and flush |
class VkTestContextImpl : public sk_gpu_test::VkTestContext { |
public: |